@@ -547,7 +547,7 @@ class TestPaginateQueryActualSQL(test_base.BaseTestCase):
         )
 
 
-class TestMigrationUtils(db_test_base.DbTestCase):
+class TestMigrationUtils(db_test_base._DbTestCase):
 
     """Class for testing utils that are used in db migrations."""
 
@@ -957,14 +957,14 @@ class TestMigrationUtils(db_test_base.DbTestCase):
 
 
 class PostgresqlTestMigrations(TestMigrationUtils,
-                               db_test_base.PostgreSQLOpportunisticTestCase):
+                               db_test_base._PostgreSQLOpportunisticTestCase):
 
     """Test migrations on PostgreSQL."""
     pass
 
 
 class MySQLTestMigrations(TestMigrationUtils,
-                          db_test_base.MySQLOpportunisticTestCase):
+                          db_test_base._MySQLOpportunisticTestCase):
 
     """Test migrations on MySQL."""
     pass
@@ -998,34 +998,6 @@ class TestConnectionUtils(test_utils.BaseTestCase):
         patch_onconnect.start()
         self.addCleanup(patch_onconnect.stop)
 
-    def test_connect_string(self):
-        connect_string = utils.get_connect_string(**self.full_credentials)
-        self.assertEqual(self.connect_string, connect_string)
-
-    def test_connect_string_sqlite(self):
-        sqlite_credentials = {'backend': 'sqlite', 'database': 'test.db'}
-        connect_string = utils.get_connect_string(**sqlite_credentials)
-        self.assertEqual('sqlite:///test.db', connect_string)
-
-    def test_is_backend_avail(self):
-        self.mox.StubOutWithMock(sqlalchemy.engine.base.Engine, 'connect')
-        fake_connection = self.mox.CreateMockAnything()
-        fake_connection.close()
-        sqlalchemy.engine.base.Engine.connect().AndReturn(fake_connection)
-        self.mox.ReplayAll()
-
-        self.assertTrue(utils.is_backend_avail(**self.full_credentials))
-
-    def test_is_backend_unavail(self):
-        log = self.useFixture(fixtures.FakeLogger())
-        err = OperationalError("Can't connect to database", None, None)
-        error_msg = "The postgresql backend is unavailable: %s\n" % err
-        self.mox.StubOutWithMock(sqlalchemy.engine.base.Engine, 'connect')
-        sqlalchemy.engine.base.Engine.connect().AndRaise(err)
-        self.mox.ReplayAll()
-        self.assertFalse(utils.is_backend_avail(**self.full_credentials))
-        self.assertEqual(error_msg, log.output)
-
     def test_ensure_backend_available(self):
         self.mox.StubOutWithMock(sqlalchemy.engine.base.Engine, 'connect')
         fake_connection = self.mox.CreateMockAnything()
@@ -1079,11 +1051,6 @@ class TestConnectionUtils(test_utils.BaseTestCase):
         self.assertEqual(('dude', 'pass', 'test', 'localhost'),
                          utils.get_db_connection_info(conn_pieces))
 
-    def test_connect_string_host(self):
-        self.full_credentials['host'] = 'myhost'
-        connect_string = utils.get_connect_string(**self.full_credentials)
-        self.assertEqual('postgresql://dude:pass@myhost/test', connect_string)
-
 
 class MyModelSoftDeletedProjectId(declarative_base(), models.ModelBase,
                                   models.SoftDeleteMixin):
@@ -1179,7 +1146,7 @@ class TestModelQuery(test_base.BaseTestCase):
         self.session.query.assert_called_with(MyModel.id)
 
 
-class TestUtils(db_test_base.DbTestCase):
+class TestUtils(db_test_base._DbTestCase):
     def setUp(self):
         super(TestUtils, self).setUp()
         meta = MetaData(bind=self.engine)
@@ -1255,12 +1222,12 @@ class TestUtils(db_test_base.DbTestCase):
 
 
 class TestUtilsMysqlOpportunistically(
-        TestUtils, db_test_base.MySQLOpportunisticTestCase):
+        TestUtils, db_test_base._MySQLOpportunisticTestCase):
     pass
 
 
 class TestUtilsPostgresqlOpportunistically(
-        TestUtils, db_test_base.PostgreSQLOpportunisticTestCase):
+        TestUtils, db_test_base._PostgreSQLOpportunisticTestCase):
     pass
 
 
@@ -1569,7 +1536,7 @@ class TestDialectFunctionDispatcher(test_base.BaseTestCase):
         )
 
 
-class TestGetInnoDBTables(db_test_base.MySQLOpportunisticTestCase):
+class TestGetInnoDBTables(db_test_base._MySQLOpportunisticTestCase):
 
     def test_all_tables_use_innodb(self):
         self.engine.execute("CREATE TABLE customers "
